# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.slashing.v1beta1 import slashing_pb2 as cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/slashing/v1beta1/query.proto\x12\x17\x63osmos.slashing.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a&cosmos/slashing/v1beta1/slashing.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\x14\n\x12QueryParamsRequest\"Q\n\x13QueryParamsResponse\x12:\n\x06params\x18\x01 \x01(\x0b\x32\x1f.cosmos.slashing.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"R\n\x17QuerySigningInfoRequest\x12\x37\n\x0c\x63ons_address\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ConsensusAddressString\"n\n\x18QuerySigningInfoResponse\x12R\n\x10val_signing_info\x18\x01 \x01(\x0b\x32-.cosmos.slashing.v1beta1.ValidatorSigningInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"V\n\x18QuerySigningInfosRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xa0\x01\n\x19QuerySigningInfosResponse\x12\x46\n\x04info\x18\x01 \x03(\x0b\x32-.cosmos.slashing.v1beta1.ValidatorSigningInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xf2\x03\n\x05Query\x12\x8c\x01\n\x06Params\x12+.cosmos.slashing.v1beta1.QueryParamsRequest\x1a,.cosmos.slashing.v1beta1.QueryParamsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/cosmos/slashing/v1beta1/params\x12\xb1\x01\n\x0bSigningInfo\x12\x30.cosmos.slashing.v1beta1.QuerySigningInfoRequest\x1a\x31.cosmos.slashing.v1beta1.QuerySigningInfoResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/cosmos/slashing/v1beta1/signing_infos/{cons_address}\x12\xa5\x01\n\x0cSigningInfos\x12\x31.cosmos.slashing.v1beta1.QuerySigningInfosRequest\x1a\x32.cosmos.slashing.v1beta1.QuerySigningInfosResponse\".\x82\xd3\xe4\x93\x02(\x12&/cosmos/slashing/v1beta1/signing_infosB/Z-github.com/cosmos/cosmos-sdk/x/slashing/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYSIGNINGINFOREQUEST'].fields_by_name['cons_address']._loaded_options = None
  _globals['_QUERYSIGNINGINFOREQUEST'].fields_by_name['cons_address']._serialized_options = b'\322\264-\035cosmos.ConsensusAddressString'
  _globals['_QUERYSIGNINGINFORESPONSE'].fields_by_name['val_signing_info']._loaded_options = None
  _globals['_QUERYSIGNINGINFORESPONSE'].fields_by_name['val_signing_info']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYSIGNINGINFOSRESPONSE'].fields_by_name['info']._loaded_options = None
  _globals['_QUERYSIGNINGINFOSRESPONSE'].fields_by_name['info']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002!\022\037/cosmos/slashing/v1beta1/params'
  _globals['_QUERY'].methods_by_name['SigningInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SigningInfo']._serialized_options = b'\202\323\344\223\0027\0225/cosmos/slashing/v1beta1/signing_infos/{cons_address}'
  _globals['_QUERY'].methods_by_name['SigningInfos']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SigningInfos']._serialized_options = b'\202\323\344\223\002(\022&/cosmos/slashing/v1beta1/signing_infos'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=246
  _globals['_QUERYPARAMSREQUEST']._serialized_end=266
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=268
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=349
  _globals['_QUERYSIGNINGINFOREQUEST']._serialized_start=351
  _globals['_QUERYSIGNINGINFOREQUEST']._serialized_end=433
  _globals['_QUERYSIGNINGINFORESPONSE']._serialized_start=435
  _globals['_QUERYSIGNINGINFORESPONSE']._serialized_end=545
  _globals['_QUERYSIGNINGINFOSREQUEST']._serialized_start=547
  _globals['_QUERYSIGNINGINFOSREQUEST']._serialized_end=633
  _globals['_QUERYSIGNINGINFOSRESPONSE']._serialized_start=636
  _globals['_QUERYSIGNINGINFOSRESPONSE']._serialized_end=796
  _globals['_QUERY']._serialized_start=799
  _globals['_QUERY']._serialized_end=1297
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/block_rate_limit_config.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/dydxprotocol/clob/block_rate_limit_config.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\"\xac\x03\n\x1b\x42lockRateLimitConfiguration\x12]\n\"max_short_term_orders_per_n_blocks\x18\x01 \x03(\x0b\x32).dydxprotocol.clob.MaxPerNBlocksRateLimitB\x06\x18\x01\xc8\xde\x1f\x00\x12Y\n max_stateful_orders_per_n_blocks\x18\x02 \x03(\x0b\x32).dydxprotocol.clob.MaxPerNBlocksRateLimitB\x04\xc8\xde\x1f\x00\x12j\n/max_short_term_order_cancellations_per_n_blocks\x18\x03 \x03(\x0b\x32).dydxprotocol.clob.MaxPerNBlocksRateLimitB\x06\x18\x01\xc8\xde\x1f\x00\x12g\n.max_short_term_orders_and_cancels_per_n_blocks\x18\x04 \x03(\x0b\x32).dydxprotocol.clob.MaxPerNBlocksRateLimitB\x04\xc8\xde\x1f\x00\";\n\x16MaxPerNBlocksRateLimit\x12\x12\n\nnum_blocks\x18\x01 \x01(\r\x12\r\n\x05limit\x18\x02 \x01(\rB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.block_rate_limit_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_orders_per_n_blocks']._loaded_options = None
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_orders_per_n_blocks']._serialized_options = b'\030\001\310\336\037\000'
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_stateful_orders_per_n_blocks']._loaded_options = None
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_stateful_orders_per_n_blocks']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_order_cancellations_per_n_blocks']._loaded_options = None
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_order_cancellations_per_n_blocks']._serialized_options = b'\030\001\310\336\037\000'
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_orders_and_cancels_per_n_blocks']._loaded_options = None
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_orders_and_cancels_per_n_blocks']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKRATELIMITCONFIGURATION']._serialized_start=93
  _globals['_BLOCKRATELIMITCONFIGURATION']._serialized_end=521
  _globals['_MAXPERNBLOCKSRATELIMIT']._serialized_start=523
  _globals['_MAXPERNBLOCKSRATELIMIT']._serialized_end=582
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MarketParam(_message.Message):
    __slots__ = ("id", "pair", "exponent", "min_exchanges", "min_price_change_ppm", "exchange_config_json")
    ID_FIELD_NUMBER: _ClassVar[int]
    PAIR_FIELD_NUMBER: _ClassVar[int]
    EXPONENT_FIELD_NUMBER: _ClassVar[int]
    MIN_EXCHANGES_FIELD_NUMBER: _ClassVar[int]
    MIN_PRICE_CHANGE_PPM_FIELD_NUMBER: _ClassVar[int]
    EXCHANGE_CONFIG_JSON_FIELD_NUMBER: _ClassVar[int]
    id: int
    pair: str
    exponent: int
    min_exchanges: int
    min_price_change_ppm: int
    exchange_config_json: str
    def __init__(self, id: _Optional[int] = ..., pair: _Optional[str] = ..., exponent: _Optional[int] = ..., min_exchanges: _Optional[int] = ..., min_price_change_ppm: _Optional[int] = ..., exchange_config_json: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/store/snapshots/v1/snapshot.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(cosmos/store/snapshots/v1/snapshot.proto\x12\x19\x63osmos.store.snapshots.v1\x1a\x14gogoproto/gogo.proto\"\x85\x01\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12;\n\x08metadata\x18\x05 \x01(\x0b\x32#.cosmos.store.snapshots.v1.MetadataB\x04\xc8\xde\x1f\x00\" \n\x08Metadata\x12\x14\n\x0c\x63hunk_hashes\x18\x01 \x03(\x0c\"\xb5\x02\n\x0cSnapshotItem\x12=\n\x05store\x18\x01 \x01(\x0b\x32,.cosmos.store.snapshots.v1.SnapshotStoreItemH\x00\x12\x45\n\x04iavl\x18\x02 \x01(\x0b\x32+.cosmos.store.snapshots.v1.SnapshotIAVLItemB\x08\xe2\xde\x1f\x04IAVLH\x00\x12\x45\n\textension\x18\x03 \x01(\x0b\x32\x30.cosmos.store.snapshots.v1.SnapshotExtensionMetaH\x00\x12P\n\x11\x65xtension_payload\x18\x04 \x01(\x0b\x32\x33.cosmos.store.snapshots.v1.SnapshotExtensionPayloadH\x00\x42\x06\n\x04item\"!\n\x11SnapshotStoreItem\x12\x0c\n\x04name\x18\x01 \x01(\t\"O\n\x10SnapshotIAVLItem\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x0f\n\x07version\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x05\"5\n\x15SnapshotExtensionMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\"+\n\x18SnapshotExtensionPayload\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x42$Z\"cosmossdk.io/store/snapshots/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.store.snapshots.v1.snapshot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\"cosmossdk.io/store/snapshots/types'
  _globals['_SNAPSHOT'].fields_by_name['metadata']._loaded_options = None
  _globals['_SNAPSHOT'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _globals['_SNAPSHOTITEM'].fields_by_name['iavl']._loaded_options = None
  _globals['_SNAPSHOTITEM'].fields_by_name['iavl']._serialized_options = b'\342\336\037\004IAVL'
  _globals['_SNAPSHOT']._serialized_start=94
  _globals['_SNAPSHOT']._serialized_end=227
  _globals['_METADATA']._serialized_start=229
  _globals['_METADATA']._serialized_end=261
  _globals['_SNAPSHOTITEM']._serialized_start=264
  _globals['_SNAPSHOTITEM']._serialized_end=573
  _globals['_SNAPSHOTSTOREITEM']._serialized_start=575
  _globals['_SNAPSHOTSTOREITEM']._serialized_end=608
  _globals['_SNAPSHOTIAVLITEM']._serialized_start=610
  _globals['_SNAPSHOTIAVLITEM']._serialized_end=689
  _globals['_SNAPSHOTEXTENSIONMETA']._serialized_start=691
  _globals['_SNAPSHOTEXTENSIONMETA']._serialized_end=744
  _globals['_SNAPSHOTEXTENSIONPAYLOAD']._serialized_start=746
  _globals['_SNAPSHOTEXTENSIONPAYLOAD']._serialized_end=789
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/genutil/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/genutil/v1beta1/genesis.proto\x12\x16\x63osmos.genutil.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"W\n\x0cGenesisState\x12G\n\x07gen_txs\x18\x01 \x03(\x0c\x42\x36\xea\xde\x1f\x06gentxs\xfa\xde\x1f\x18\x65ncoding/json.RawMessage\xa2\xe7\xb0*\x06gentxs\xa8\xe7\xb0*\x01\x42.Z,github.com/cosmos/cosmos-sdk/x/genutil/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.genutil.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/genutil/types'
  _globals['_GENESISSTATE'].fields_by_name['gen_txs']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['gen_txs']._serialized_options = b'\352\336\037\006gentxs\372\336\037\030encoding/json.RawMessage\242\347\260*\006gentxs\250\347\260*\001'
  _globals['_GENESISSTATE']._serialized_start=105
  _globals['_GENESISSTATE']._serialized_end=192
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PerpetualFeeParams(_message.Message):
    __slots__ = ("tiers",)
    TIERS_FIELD_NUMBER: _ClassVar[int]
    tiers: _containers.RepeatedCompositeFieldContainer[PerpetualFeeTier]
    def __init__(self, tiers: _Optional[_Iterable[_Union[PerpetualFeeTier, _Mapping]]] = ...) -> None: ...

class PerpetualFeeTier(_message.Message):
    __slots__ = ("name", "absolute_volume_requirement", "total_volume_share_requirement_ppm", "maker_volume_share_requirement_ppm", "maker_fee_ppm", "taker_fee_ppm")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ABSOLUTE_VOLUME_REQUIREMENT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOLUME_SHARE_REQUIREMENT_PPM_FIELD_NUMBER: _ClassVar[int]
    MAKER_VOLUME_SHARE_REQUIREMENT_PPM_FIELD_NUMBER: _ClassVar[int]
    MAKER_FEE_PPM_FIELD_NUMBER: _ClassVar[int]
    TAKER_FEE_PPM_FIELD_NUMBER: _ClassVar[int]
    name: str
    absolute_volume_requirement: int
    total_volume_share_requirement_ppm: int
    maker_volume_share_requirement_ppm: int
    maker_fee_ppm: int
    taker_fee_ppm: int
    def __init__(self, name: _Optional[str] = ..., absolute_volume_requirement: _Optional[int] = ..., total_volume_share_requirement_ppm: _Optional[int] = ..., maker_volume_share_requirement_ppm: _Optional[int] = ..., maker_fee_ppm: _Optional[int] = ..., taker_fee_ppm: _Optional[int] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AccountState(_message.Message):
    __slots__ = ("address", "timestamp_nonce_details")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_NONCE_DETAILS_FIELD_NUMBER: _ClassVar[int]
    address: str
    timestamp_nonce_details: TimestampNonceDetails
    def __init__(self, address: _Optional[str] = ..., timestamp_nonce_details: _Optional[_Union[TimestampNonceDetails, _Mapping]] = ...) -> None: ...

class TimestampNonceDetails(_message.Message):
    __slots__ = ("timestamp_nonces", "max_ejected_nonce")
    TIMESTAMP_NONCES_FIELD_NUMBER: _ClassVar[int]
    MAX_EJECTED_NONCE_FIELD_NUMBER: _ClassVar[int]
    timestamp_nonces: _containers.RepeatedScalarFieldContainer[int]
    max_ejected_nonce: int
    def __init__(self, timestamp_nonces: _Optional[_Iterable[int]] = ..., max_ejected_nonce: _Optional[int] = ...) -> None: ...



from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.abci.v1beta1 import abci_pb2 as _abci_pb2
from v4_proto.cosmos.tx.v1beta1 import tx_pb2 as _tx_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.tendermint.types import block_pb2 as _block_pb2
from v4_proto.tendermint.types import types_pb2 as _types_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OrderBy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ORDER_BY_UNSPECIFIED: _ClassVar[OrderBy]
    ORDER_BY_ASC: _ClassVar[OrderBy]
    ORDER_BY_DESC: _ClassVar[OrderBy]

class BroadcastMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    BROADCAST_MODE_UNSPECIFIED: _ClassVar[BroadcastMode]
    BROADCAST_MODE_BLOCK: _ClassVar[BroadcastMode]
    BROADCAST_MODE_SYNC: _ClassVar[BroadcastMode]
    BROADCAST_MODE_ASYNC: _ClassVar[BroadcastMode]
ORDER_BY_UNSPECIFIED: OrderBy
ORDER_BY_ASC: OrderBy
ORDER_BY_DESC: OrderBy
BROADCAST_MODE_UNSPECIFIED: BroadcastMode
BROADCAST_MODE_BLOCK: BroadcastMode
BROADCAST_MODE_SYNC: BroadcastMode
BROADCAST_MODE_ASYNC: BroadcastMode

class GetTxsEventRequest(_message.Message):
    __slots__ = ("events", "pagination", "order_by", "page", "limit", "query")
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedScalarFieldContainer[str]
    pagination: _pagination_pb2.PageRequest
    order_by: OrderBy
    page: int
    limit: int
    query: str
    def __init__(self, events: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ..., order_by: _Optional[_Union[OrderBy, str]] = ..., page: _Optional[int] = ..., limit: _Optional[int] = ..., query: _Optional[str] = ...) -> None: ...

class GetTxsEventResponse(_message.Message):
    __slots__ = ("txs", "tx_responses", "pagination", "total")
    TXS_FIELD_NUMBER: _ClassVar[int]
    TX_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedCompositeFieldContainer[_tx_pb2.Tx]
    tx_responses: _containers.RepeatedCompositeFieldContainer[_abci_pb2.TxResponse]
    pagination: _pagination_pb2.PageResponse
    total: int
    def __init__(self, txs: _Optional[_Iterable[_Union[_tx_pb2.Tx, _Mapping]]] = ..., tx_responses: _Optional[_Iterable[_Union[_abci_pb2.TxResponse, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ..., total: _Optional[int] = ...) -> None: ...

class BroadcastTxRequest(_message.Message):
    __slots__ = ("tx_bytes", "mode")
    TX_BYTES_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    tx_bytes: bytes
    mode: BroadcastMode
    def __init__(self, tx_bytes: _Optional[bytes] = ..., mode: _Optional[_Union[BroadcastMode, str]] = ...) -> None: ...

class BroadcastTxResponse(_message.Message):
    __slots__ = ("tx_response",)
    TX_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    tx_response: _abci_pb2.TxResponse
    def __init__(self, tx_response: _Optional[_Union[_abci_pb2.TxResponse, _Mapping]] = ...) -> None: ...

class SimulateRequest(_message.Message):
    __slots__ = ("tx", "tx_bytes")
    TX_FIELD_NUMBER: _ClassVar[int]
    TX_BYTES_FIELD_NUMBER: _ClassVar[int]
    tx: _tx_pb2.Tx
    tx_bytes: bytes
    def __init__(self, tx: _Optional[_Union[_tx_pb2.Tx, _Mapping]] = ..., tx_bytes: _Optional[bytes] = ...) -> None: ...

class SimulateResponse(_message.Message):
    __slots__ = ("gas_info", "result")
    GAS_INFO_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    gas_info: _abci_pb2.GasInfo
    result: _abci_pb2.Result
    def __init__(self, gas_info: _Optional[_Union[_abci_pb2.GasInfo, _Mapping]] = ..., result: _Optional[_Union[_abci_pb2.Result, _Mapping]] = ...) -> None: ...

class GetTxRequest(_message.Message):
    __slots__ = ("hash",)
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash: str
    def __init__(self, hash: _Optional[str] = ...) -> None: ...

class GetTxResponse(_message.Message):
    __slots__ = ("tx", "tx_response")
    TX_FIELD_NUMBER: _ClassVar[int]
    TX_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    tx: _tx_pb2.Tx
    tx_response: _abci_pb2.TxResponse
    def __init__(self, tx: _Optional[_Union[_tx_pb2.Tx, _Mapping]] = ..., tx_response: _Optional[_Union[_abci_pb2.TxResponse, _Mapping]] = ...) -> None: ...

class GetBlockWithTxsRequest(_message.Message):
    __slots__ = ("height", "pagination")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    height: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, height: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class GetBlockWithTxsResponse(_message.Message):
    __slots__ = ("txs", "block_id", "block", "pagination")
    TXS_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedCompositeFieldContainer[_tx_pb2.Tx]
    block_id: _types_pb2.BlockID
    block: _block_pb2.Block
    pagination: _pagination_pb2.PageResponse
    def __init__(self, txs: _Optional[_Iterable[_Union[_tx_pb2.Tx, _Mapping]]] = ..., block_id: _Optional[_Union[_types_pb2.BlockID, _Mapping]] = ..., block: _Optional[_Union[_block_pb2.Block, _Mapping]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class TxDecodeRequest(_message.Message):
    __slots__ = ("tx_bytes",)
    TX_BYTES_FIELD_NUMBER: _ClassVar[int]
    tx_bytes: bytes
    def __init__(self, tx_bytes: _Optional[bytes] = ...) -> None: ...

class TxDecodeResponse(_message.Message):
    __slots__ = ("tx",)
    TX_FIELD_NUMBER: _ClassVar[int]
    tx: _tx_pb2.Tx
    def __init__(self, tx: _Optional[_Union[_tx_pb2.Tx, _Mapping]] = ...) -> None: ...

class TxEncodeRequest(_message.Message):
    __slots__ = ("tx",)
    TX_FIELD_NUMBER: _ClassVar[int]
    tx: _tx_pb2.Tx
    def __init__(self, tx: _Optional[_Union[_tx_pb2.Tx, _Mapping]] = ...) -> None: ...

class TxEncodeResponse(_message.Message):
    __slots__ = ("tx_bytes",)
    TX_BYTES_FIELD_NUMBER: _ClassVar[int]
    tx_bytes: bytes
    def __init__(self, tx_bytes: _Optional[bytes] = ...) -> None: ...

class TxEncodeAminoRequest(_message.Message):
    __slots__ = ("amino_json",)
    AMINO_JSON_FIELD_NUMBER: _ClassVar[int]
    amino_json: str
    def __init__(self, amino_json: _Optional[str] = ...) -> None: ...

class TxEncodeAminoResponse(_message.Message):
    __slots__ = ("amino_binary",)
    AMINO_BINARY_FIELD_NUMBER: _ClassVar[int]
    amino_binary: bytes
    def __init__(self, amino_binary: _Optional[bytes] = ...) -> None: ...

class TxDecodeAminoRequest(_message.Message):
    __slots__ = ("amino_binary",)
    AMINO_BINARY_FIELD_NUMBER: _ClassVar[int]
    amino_binary: bytes
    def __init__(self, amino_binary: _Optional[bytes] = ...) -> None: ...

class TxDecodeAminoResponse(_message.Message):
    __slots__ = ("amino_json",)
    AMINO_JSON_FIELD_NUMBER: _ClassVar[int]
    amino_json: str
    def __init__(self, amino_json: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vault/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64ydxprotocol/vault/tx.proto\x12\x12\x64ydxprotocol.vault\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\x1a\x14gogoproto/gogo.proto\"\xf7\x01\n\x11MsgDepositToVault\x12-\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultId\x12=\n\rsubaccount_id\x18\x02 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12`\n\x0equote_quantums\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x12\x82\xe7\xb0*\rsubaccount_id\"\x1b\n\x19MsgDepositToVaultResponse\"\xa5\x01\n\x1dMsgUpdateDefaultQuotingParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12G\n\x16\x64\x65\x66\x61ult_quoting_params\x18\x02 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\'\n%MsgUpdateDefaultQuotingParamsResponse\"\xcd\x01\n\x18MsgSetVaultQuotingParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x08vault_id\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12?\n\x0equoting_params\x18\x03 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\"\n MsgSetVaultQuotingParamsResponse2\xf7\x02\n\x03Msg\x12\x66\n\x0e\x44\x65positToVault\x12%.dydxprotocol.vault.MsgDepositToVault\x1a-.dydxprotocol.vault.MsgDepositToVaultResponse\x12\x8a\x01\n\x1aUpdateDefaultQuotingParams\x12\x31.dydxprotocol.vault.MsgUpdateDefaultQuotingParams\x1a\x39.dydxprotocol.vault.MsgUpdateDefaultQuotingParamsResponse\x12{\n\x15SetVaultQuotingParams\x12,.dydxprotocol.vault.MsgSetVaultQuotingParams\x1a\x34.dydxprotocol.vault.MsgSetVaultQuotingParamsResponseB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_MSGDEPOSITTOVAULT'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGDEPOSITTOVAULT'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGDEPOSITTOVAULT']._loaded_options = None
  _globals['_MSGDEPOSITTOVAULT']._serialized_options = b'\202\347\260*\rsubaccount_id'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['default_quoting_params']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['default_quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['vault_id']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['quoting_params']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTQUOTINGPARAMS']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGDEPOSITTOVAULT']._serialized_start=234
  _globals['_MSGDEPOSITTOVAULT']._serialized_end=481
  _globals['_MSGDEPOSITTOVAULTRESPONSE']._serialized_start=483
  _globals['_MSGDEPOSITTOVAULTRESPONSE']._serialized_end=510
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_start=513
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_end=678
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMSRESPONSE']._serialized_start=680
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMSRESPONSE']._serialized_end=719
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_start=722
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_end=927
  _globals['_MSGSETVAULTQUOTINGPARAMSRESPONSE']._serialized_start=929
  _globals['_MSGSETVAULTQUOTINGPARAMSRESPONSE']._serialized_end=963
  _globals['_MSG']._serialized_start=966
  _globals['_MSG']._serialized_end=1341
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DowntimeParams(_message.Message):
    __slots__ = ("durations",)
    DURATIONS_FIELD_NUMBER: _ClassVar[int]
    durations: _containers.RepeatedCompositeFieldContainer[_duration_pb2.Duration]
    def __init__(self, durations: _Optional[_Iterable[_Union[_duration_pb2.Duration, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/staking.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from v4_proto.tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/staking/v1beta1/staking.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\x1a\x1ctendermint/types/types.proto\x1a\x1btendermint/abci/types.proto\"\x83\x01\n\x0eHistoricalInfo\x12\x33\n\x06header\x18\x01 \x01(\x0b\x32\x18.tendermint.types.HeaderB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12<\n\x06valset\x18\x02 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\xf8\x01\n\x0f\x43ommissionRates\x12\x44\n\x04rate\x18\x01 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12H\n\x08max_rate\x18\x02 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12O\n\x0fmax_change_rate\x18\x03 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01:\x04\xe8\xa0\x1f\x01\"\xa4\x01\n\nCommission\x12P\n\x10\x63ommission_rates\x18\x01 \x01(\x0b\x32\'.cosmos.staking.v1beta1.CommissionRatesB\r\xc8\xde\x1f\x00\xd0\xde\x1f\x01\xa8\xe7\xb0*\x01\x12>\n\x0bupdate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01:\x04\xe8\xa0\x1f\x01\"r\n\x0b\x44\x65scription\x12\x0f\n\x07moniker\x18\x01 \x01(\t\x12\x10\n\x08identity\x18\x02 \x01(\t\x12\x0f\n\x07website\x18\x03 \x01(\t\x12\x18\n\x10security_contact\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t:\x04\xe8\xa0\x1f\x01\"\xcc\x05\n\tValidator\x12\x32\n\x10operator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12H\n\x10\x63onsensus_pubkey\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x18\xca\xb4-\x14\x63osmos.crypto.PubKey\x12\x0e\n\x06jailed\x18\x03 \x01(\x08\x12\x32\n\x06status\x18\x04 \x01(\x0e\x32\".cosmos.staking.v1beta1.BondStatus\x12;\n\x06tokens\x18\x05 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\x12K\n\x10\x64\x65legator_shares\x18\x06 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\x12\x43\n\x0b\x64\x65scription\x18\x07 \x01(\x0b\x32#.cosmos.staking.v1beta1.DescriptionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x18\n\x10unbonding_height\x18\x08 \x01(\x03\x12\x41\n\x0eunbonding_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x41\n\ncommission\x18\n \x01(\x0b\x32\".cosmos.staking.v1beta1.CommissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12H\n\x13min_self_delegation\x18\x0b \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\x12#\n\x1bunbonding_on_hold_ref_count\x18\x0c \x01(\x03\x12\x15\n\runbonding_ids\x18\r \x03(\x04:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\";\n\x0cValAddresses\x12+\n\taddresses\x18\x01 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\x85\x01\n\x06\x44VPair\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"C\n\x07\x44VPairs\x12\x38\n\x05pairs\x18\x01 \x03(\x0b\x32\x1e.cosmos.staking.v1beta1.DVPairB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\xcf\x01\n\nDVVTriplet\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12@\n\x15validator_src_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12@\n\x15validator_dst_address\x18\x03 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"N\n\x0b\x44VVTriplets\x12?\n\x08triplets\x18\x01 \x03(\x0b\x32\".cosmos.staking.v1beta1.DVVTripletB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\xcc\x01\n\nDelegation\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12\x41\n\x06shares\x18\x03 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xe0\x01\n\x13UnbondingDelegation\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12L\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x30.cosmos.staking.v1beta1.UnbondingDelegationEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xbc\x02\n\x18UnbondingDelegationEntry\x12\x17\n\x0f\x63reation_height\x18\x01 \x01(\x03\x12\x42\n\x0f\x63ompletion_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x44\n\x0finitial_balance\x18\x03 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\x12<\n\x07\x62\x61lance\x18\x04 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\x12\x14\n\x0cunbonding_id\x18\x05 \x01(\x04\x12#\n\x1bunbonding_on_hold_ref_count\x18\x06 \x01(\x03:\x04\xe8\xa0\x1f\x01\"\xbe\x02\n\x11RedelegationEntry\x12\x17\n\x0f\x63reation_height\x18\x01 \x01(\x03\x12\x42\n\x0f\x63ompletion_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x44\n\x0finitial_balance\x18\x03 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\x12\x45\n\nshares_dst\x18\x04 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\x12\x14\n\x0cunbonding_id\x18\x05 \x01(\x04\x12#\n\x1bunbonding_on_hold_ref_count\x18\x06 \x01(\x03:\x04\xe8\xa0\x1f\x01\"\x98\x02\n\x0cRedelegation\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12@\n\x15validator_src_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12@\n\x15validator_dst_address\x18\x03 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12\x45\n\x07\x65ntries\x18\x04 \x03(\x0b\x32).cosmos.staking.v1beta1.RedelegationEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xc0\x02\n\x06Params\x12@\n\x0eunbonding_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x16\n\x0emax_validators\x18\x02 \x01(\r\x12\x13\n\x0bmax_entries\x18\x03 \x01(\r\x12\x1a\n\x12historical_entries\x18\x04 \x01(\r\x12\x12\n\nbond_denom\x18\x05 \x01(\t\x12q\n\x13min_commission_rate\x18\x06 \x01(\tBT\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x1ayaml:\"min_commission_rate\"\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01:$\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x1b\x63osmos-sdk/x/staking/Params\"\x94\x01\n\x12\x44\x65legationResponse\x12\x41\n\ndelegation\x18\x01 \x01(\x0b\x32\".cosmos.staking.v1beta1.DelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x35\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x04\xe8\xa0\x1f\x00\"\xb1\x01\n\x19RedelegationEntryResponse\x12P\n\x12redelegation_entry\x18\x01 \x01(\x0b\x32).cosmos.staking.v1beta1.RedelegationEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12<\n\x07\x62\x61lance\x18\x04 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int:\x04\xe8\xa0\x1f\x01\"\xb2\x01\n\x14RedelegationResponse\x12\x45\n\x0credelegation\x18\x01 \x01(\x0b\x32$.cosmos.staking.v1beta1.RedelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12M\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x31.cosmos.staking.v1beta1.RedelegationEntryResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x04\xe8\xa0\x1f\x00\"\xcc\x01\n\x04Pool\x12`\n\x11not_bonded_tokens\x18\x01 \x01(\tBE\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xea\xde\x1f\x11not_bonded_tokens\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01\x12X\n\rbonded_tokens\x18\x02 \x01(\tBA\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xea\xde\x1f\rbonded_tokens\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01:\x08\xe8\xa0\x1f\x01\xf0\xa0\x1f\x01\"P\n\x10ValidatorUpdates\x12<\n\x07updates\x18\x01 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01*\xb6\x01\n\nBondStatus\x12,\n\x17\x42OND_STATUS_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUnspecified\x12&\n\x14\x42OND_STATUS_UNBONDED\x10\x01\x1a\x0c\x8a\x9d \x08Unbonded\x12(\n\x15\x42OND_STATUS_UNBONDING\x10\x02\x1a\r\x8a\x9d \tUnbonding\x12\"\n\x12\x42OND_STATUS_BONDED\x10\x03\x1a\n\x8a\x9d \x06\x42onded\x1a\x04\x88\xa3\x1e\x00*]\n\nInfraction\x12\x1a\n\x16INFRACTION_UNSPECIFIED\x10\x00\x12\x1a\n\x16INFRACTION_DOUBLE_SIGN\x10\x01\x12\x17\n\x13INFRACTION_DOWNTIME\x10\x02\x42.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.staking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _globals['_BONDSTATUS']._loaded_options = None
  _globals['_BONDSTATUS']._serialized_options = b'\210\243\036\000'
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNSPECIFIED"]._loaded_options = None
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNSPECIFIED"]._serialized_options = b'\212\235 \013Unspecified'
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNBONDED"]._loaded_options = None
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNBONDED"]._serialized_options = b'\212\235 \010Unbonded'
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNBONDING"]._loaded_options = None
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNBONDING"]._serialized_options = b'\212\235 \tUnbonding'
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_BONDED"]._loaded_options = None
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_BONDED"]._serialized_options = b'\212\235 \006Bonded'
  _globals['_HISTORICALINFO'].fields_by_name['header']._loaded_options = None
  _globals['_HISTORICALINFO'].fields_by_name['header']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_HISTORICALINFO'].fields_by_name['valset']._loaded_options = None
  _globals['_HISTORICALINFO'].fields_by_name['valset']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_COMMISSIONRATES'].fields_by_name['rate']._loaded_options = None
  _globals['_COMMISSIONRATES'].fields_by_name['rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_COMMISSIONRATES'].fields_by_name['max_rate']._loaded_options = None
  _globals['_COMMISSIONRATES'].fields_by_name['max_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_COMMISSIONRATES'].fields_by_name['max_change_rate']._loaded_options = None
  _globals['_COMMISSIONRATES'].fields_by_name['max_change_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_COMMISSIONRATES']._loaded_options = None
  _globals['_COMMISSIONRATES']._serialized_options = b'\350\240\037\001'
  _globals['_COMMISSION'].fields_by_name['commission_rates']._loaded_options = None
  _globals['_COMMISSION'].fields_by_name['commission_rates']._serialized_options = b'\310\336\037\000\320\336\037\001\250\347\260*\001'
  _globals['_COMMISSION'].fields_by_name['update_time']._loaded_options = None
  _globals['_COMMISSION'].fields_by_name['update_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_COMMISSION']._loaded_options = None
  _globals['_COMMISSION']._serialized_options = b'\350\240\037\001'
  _globals['_DESCRIPTION']._loaded_options = None
  _globals['_DESCRIPTION']._serialized_options = b'\350\240\037\001'
  _globals['_VALIDATOR'].fields_by_name['operator_address']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['operator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_VALIDATOR'].fields_by_name['consensus_pubkey']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['consensus_pubkey']._serialized_options = b'\312\264-\024cosmos.crypto.PubKey'
  _globals['_VALIDATOR'].fields_by_name['tokens']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['tokens']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_VALIDATOR'].fields_by_name['delegator_shares']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['delegator_shares']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_VALIDATOR'].fields_by_name['description']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['description']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_VALIDATOR'].fields_by_name['unbonding_time']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['unbonding_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_VALIDATOR'].fields_by_name['commission']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['commission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_VALIDATOR'].fields_by_name['min_self_delegation']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['min_self_delegation']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_VALIDATOR']._loaded_options = None
  _globals['_VALIDATOR']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_VALADDRESSES'].fields_by_name['addresses']._loaded_options = None
  _globals['_VALADDRESSES'].fields_by_name['addresses']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DVPAIR'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_DVPAIR'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DVPAIR'].fields_by_name['validator_address']._loaded_options = None
  _globals['_DVPAIR'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_DVPAIR']._loaded_options = None
  _globals['_DVPAIR']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_DVPAIRS'].fields_by_name['pairs']._loaded_options = None
  _globals['_DVPAIRS'].fields_by_name['pairs']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_DVVTRIPLET'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_DVVTRIPLET'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DVVTRIPLET'].fields_by_name['validator_src_address']._loaded_options = None
  _globals['_DVVTRIPLET'].fields_by_name['validator_src_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_DVVTRIPLET'].fields_by_name['validator_dst_address']._loaded_options = None
  _globals['_DVVTRIPLET'].fields_by_name['validator_dst_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_DVVTRIPLET']._loaded_options = None
  _globals['_DVVTRIPLET']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_DVVTRIPLETS'].fields_by_name['triplets']._loaded_options = None
  _globals['_DVVTRIPLETS'].fields_by_name['triplets']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_DELEGATION'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_DELEGATION'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DELEGATION'].fields_by_name['validator_address']._loaded_options = None
  _globals['_DELEGATION'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_DELEGATION'].fields_by_name['shares']._loaded_options = None
  _globals['_DELEGATION'].fields_by_name['shares']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_DELEGATION']._loaded_options = None
  _globals['_DELEGATION']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_UNBONDINGDELEGATION'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_UNBONDINGDELEGATION'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_UNBONDINGDELEGATION'].fields_by_name['validator_address']._loaded_options = None
  _globals['_UNBONDINGDELEGATION'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_UNBONDINGDELEGATION'].fields_by_name['entries']._loaded_options = None
  _globals['_UNBONDINGDELEGATION'].fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_UNBONDINGDELEGATION']._loaded_options = None
  _globals['_UNBONDINGDELEGATION']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['completion_time']._loaded_options = None
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['initial_balance']._loaded_options = None
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['initial_balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['balance']._loaded_options = None
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_UNBONDINGDELEGATIONENTRY']._loaded_options = None
  _globals['_UNBONDINGDELEGATIONENTRY']._serialized_options = b'\350\240\037\001'
  _globals['_REDELEGATIONENTRY'].fields_by_name['completion_time']._loaded_options = None
  _globals['_REDELEGATIONENTRY'].fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_REDELEGATIONENTRY'].fields_by_name['initial_balance']._loaded_options = None
  _globals['_REDELEGATIONENTRY'].fields_by_name['initial_balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_REDELEGATIONENTRY'].fields_by_name['shares_dst']._loaded_options = None
  _globals['_REDELEGATIONENTRY'].fields_by_name['shares_dst']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_REDELEGATIONENTRY']._loaded_options = None
  _globals['_REDELEGATIONENTRY']._serialized_options = b'\350\240\037\001'
  _globals['_REDELEGATION'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_REDELEGATION'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_REDELEGATION'].fields_by_name['validator_src_address']._loaded_options = None
  _globals['_REDELEGATION'].fields_by_name['validator_src_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_REDELEGATION'].fields_by_name['validator_dst_address']._loaded_options = None
  _globals['_REDELEGATION'].fields_by_name['validator_dst_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_REDELEGATION'].fields_by_name['entries']._loaded_options = None
  _globals['_REDELEGATION'].fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_REDELEGATION']._loaded_options = None
  _globals['_REDELEGATION']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_PARAMS'].fields_by_name['unbonding_time']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['unbonding_time']._serialized_options = b'\310\336\037\000\230\337\037\001\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['min_commission_rate']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_commission_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\032yaml:\"min_commission_rate\"\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\033cosmos-sdk/x/staking/Params'
  _globals['_DELEGATIONRESPONSE'].fields_by_name['delegation']._loaded_options = None
  _globals['_DELEGATIONRESPONSE'].fields_by_name['delegation']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_DELEGATIONRESPONSE'].fields_by_name['balance']._loaded_options = None
  _globals['_DELEGATIONRESPONSE'].fields_by_name['balance']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_DELEGATIONRESPONSE']._loaded_options = None
  _globals['_DELEGATIONRESPONSE']._serialized_options = b'\350\240\037\000'
  _globals['_REDELEGATIONENTRYRESPONSE'].fields_by_name['redelegation_entry']._loaded_options = None
  _globals['_REDELEGATIONENTRYRESPONSE'].fields_by_name['redelegation_entry']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_REDELEGATIONENTRYRESPONSE'].fields_by_name['balance']._loaded_options = None
  _globals['_REDELEGATIONENTRYRESPONSE'].fields_by_name['balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_REDELEGATIONENTRYRESPONSE']._loaded_options = None
  _globals['_REDELEGATIONENTRYRESPONSE']._serialized_options = b'\350\240\037\001'
  _globals['_REDELEGATIONRESPONSE'].fields_by_name['redelegation']._loaded_options = None
  _globals['_REDELEGATIONRESPONSE'].fields_by_name['redelegation']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_REDELEGATIONRESPONSE'].fields_by_name['entries']._loaded_options = None
  _globals['_REDELEGATIONRESPONSE'].fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_REDELEGATIONRESPONSE']._loaded_options = None
  _globals['_REDELEGATIONRESPONSE']._serialized_options = b'\350\240\037\000'
  _globals['_POOL'].fields_by_name['not_bonded_tokens']._loaded_options = None
  _globals['_POOL'].fields_by_name['not_bonded_tokens']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\352\336\037\021not_bonded_tokens\322\264-\ncosmos.Int\250\347\260*\001'
  _globals['_POOL'].fields_by_name['bonded_tokens']._loaded_options = None
  _globals['_POOL'].fields_by_name['bonded_tokens']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\352\336\037\rbonded_tokens\322\264-\ncosmos.Int\250\347\260*\001'
  _globals['_POOL']._loaded_options = None
  _globals['_POOL']._serialized_options = b'\350\240\037\001\360\240\037\001'
  _globals['_VALIDATORUPDATES'].fields_by_name['updates']._loaded_options = None
  _globals['_VALIDATORUPDATES'].fields_by_name['updates']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_BONDSTATUS']._serialized_start=4740
  _globals['_BONDSTATUS']._serialized_end=4922
  _globals['_INFRACTION']._serialized_start=4924
  _globals['_INFRACTION']._serialized_end=5017
  _globals['_HISTORICALINFO']._serialized_start=316
  _globals['_HISTORICALINFO']._serialized_end=447
  _globals['_COMMISSIONRATES']._serialized_start=450
  _globals['_COMMISSIONRATES']._serialized_end=698
  _globals['_COMMISSION']._serialized_start=701
  _globals['_COMMISSION']._serialized_end=865
  _globals['_DESCRIPTION']._serialized_start=867
  _globals['_DESCRIPTION']._serialized_end=981
  _globals['_VALIDATOR']._serialized_start=984
  _globals['_VALIDATOR']._serialized_end=1700
  _globals['_VALADDRESSES']._serialized_start=1702
  _globals['_VALADDRESSES']._serialized_end=1761
  _globals['_DVPAIR']._serialized_start=1764
  _globals['_DVPAIR']._serialized_end=1897
  _globals['_DVPAIRS']._serialized_start=1899
  _globals['_DVPAIRS']._serialized_end=1966
  _globals['_DVVTRIPLET']._serialized_start=1969
  _globals['_DVVTRIPLET']._serialized_end=2176
  _globals['_DVVTRIPLETS']._serialized_start=2178
  _globals['_DVVTRIPLETS']._serialized_end=2256
  _globals['_DELEGATION']._serialized_start=2259
  _globals['_DELEGATION']._serialized_end=2463
  _globals['_UNBONDINGDELEGATION']._serialized_start=2466
  _globals['_UNBONDINGDELEGATION']._serialized_end=2690
  _globals['_UNBONDINGDELEGATIONENTRY']._serialized_start=2693
  _globals['_UNBONDINGDELEGATIONENTRY']._serialized_end=3009
  _globals['_REDELEGATIONENTRY']._serialized_start=3012
  _globals['_REDELEGATIONENTRY']._serialized_end=3330
  _globals['_REDELEGATION']._serialized_start=3333
  _globals['_REDELEGATION']._serialized_end=3613
  _globals['_PARAMS']._serialized_start=3616
  _globals['_PARAMS']._serialized_end=3936
  _globals['_DELEGATIONRESPONSE']._serialized_start=3939
  _globals['_DELEGATIONRESPONSE']._serialized_end=4087
  _globals['_REDELEGATIONENTRYRESPONSE']._serialized_start=4090
  _globals['_REDELEGATIONENTRYRESPONSE']._serialized_end=4267
  _globals['_REDELEGATIONRESPONSE']._serialized_start=4270
  _globals['_REDELEGATIONRESPONSE']._serialized_end=4448
  _globals['_POOL']._serialized_start=4451
  _globals['_POOL']._serialized_end=4655
  _globals['_VALIDATORUPDATES']._serialized_start=4657
  _globals['_VALIDATORUPDATES']._serialized_end=4737
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/bridge/bridge_event_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dydxprotocol/bridge/bridge_event_info.proto\x12\x13\x64ydxprotocol.bridge\"<\n\x0f\x42ridgeEventInfo\x12\x0f\n\x07next_id\x18\x01 \x01(\r\x12\x18\n\x10\x65th_block_height\x18\x02 \x01(\x04\x42:Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.bridge.bridge_event_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/types'
  _globals['_BRIDGEEVENTINFO']._serialized_start=68
  _globals['_BRIDGEEVENTINFO']._serialized_end=128
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.gov.v1beta1 import gov_pb2 as _gov_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("starting_proposal_id", "deposits", "votes", "proposals", "deposit_params", "voting_params", "tally_params")
    STARTING_PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    DEPOSITS_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    PROPOSALS_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    TALLY_PARAMS_FIELD_NUMBER: _ClassVar[int]
    starting_proposal_id: int
    deposits: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Deposit]
    votes: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Vote]
    proposals: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Proposal]
    deposit_params: _gov_pb2.DepositParams
    voting_params: _gov_pb2.VotingParams
    tally_params: _gov_pb2.TallyParams
    def __init__(self, starting_proposal_id: _Optional[int] = ..., deposits: _Optional[_Iterable[_Union[_gov_pb2.Deposit, _Mapping]]] = ..., votes: _Optional[_Iterable[_Union[_gov_pb2.Vote, _Mapping]]] = ..., proposals: _Optional[_Iterable[_Union[_gov_pb2.Proposal, _Mapping]]] = ..., deposit_params: _Optional[_Union[_gov_pb2.DepositParams, _Mapping]] = ..., voting_params: _Optional[_Union[_gov_pb2.VotingParams, _Mapping]] = ..., tally_params: _Optional[_Union[_gov_pb2.TallyParams, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("treasury_account", "denom", "denom_exponent", "market_id", "fee_multiplier_ppm")
    TREASURY_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    DENOM_EXPONENT_FIELD_NUMBER: _ClassVar[int]
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    FEE_MULTIPLIER_PPM_FIELD_NUMBER: _ClassVar[int]
    treasury_account: str
    denom: str
    denom_exponent: int
    market_id: int
    fee_multiplier_ppm: int
    def __init__(self, treasury_account: _Optional[str] = ..., denom: _Optional[str] = ..., denom_exponent: _Optional[int] = ..., market_id: _Optional[int] = ..., fee_multiplier_ppm: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/blocktime/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.blocktime import params_pb2 as dydxprotocol_dot_blocktime_dot_params__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/blocktime/tx.proto\x12\x16\x64ydxprotocol.blocktime\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a#dydxprotocol/blocktime/params.proto\x1a\x14gogoproto/gogo.proto\"\x94\x01\n\x17MsgUpdateDowntimeParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x06params\x18\x02 \x01(\x0b\x32&.dydxprotocol.blocktime.DowntimeParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"!\n\x1fMsgUpdateDowntimeParamsResponse2\x88\x01\n\x03Msg\x12\x80\x01\n\x14UpdateDowntimeParams\x12/.dydxprotocol.blocktime.MsgUpdateDowntimeParams\x1a\x37.dydxprotocol.blocktime.MsgUpdateDowntimeParamsResponseB=Z;github.com/dydxprotocol/v4-chain/protocol/x/blocktime/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.blocktime.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/blocktime/types'
  _globals['_MSGUPDATEDOWNTIMEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEDOWNTIMEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEDOWNTIMEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEDOWNTIMEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEDOWNTIMEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEDOWNTIMEPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEDOWNTIMEPARAMS']._serialized_start=171
  _globals['_MSGUPDATEDOWNTIMEPARAMS']._serialized_end=319
  _globals['_MSGUPDATEDOWNTIMEPARAMSRESPONSE']._serialized_start=321
  _globals['_MSGUPDATEDOWNTIMEPARAMSRESPONSE']._serialized_end=354
  _globals['_MSG']._serialized_start=357
  _globals['_MSG']._serialized_end=493
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/revshare/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dydxprotocol/revshare/params.proto\x12\x15\x64ydxprotocol.revshare\x1a\x19\x63osmos_proto/cosmos.proto\"z\n\x1eMarketMapperRevenueShareParams\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x19\n\x11revenue_share_ppm\x18\x02 \x01(\r\x12\x12\n\nvalid_days\x18\x03 \x01(\rB<Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.revshare.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/types'
  _globals['_MARKETMAPPERREVENUESHAREPARAMS'].fields_by_name['address']._loaded_options = None
  _globals['_MARKETMAPPERREVENUESHAREPARAMS'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MARKETMAPPERREVENUESHAREPARAMS']._serialized_start=88
  _globals['_MARKETMAPPERREVENUESHAREPARAMS']._serialized_end=210
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/tx/signing/v1beta1/signing.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.crypto.multisig.v1beta1 import multisig_pb2 as cosmos_dot_crypto_dot_multisig_dot_v1beta1_dot_multisig__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/tx/signing/v1beta1/signing.proto\x12\x19\x63osmos.tx.signing.v1beta1\x1a-cosmos/crypto/multisig/v1beta1/multisig.proto\x1a\x19google/protobuf/any.proto\"Z\n\x14SignatureDescriptors\x12\x42\n\nsignatures\x18\x01 \x03(\x0b\x32..cosmos.tx.signing.v1beta1.SignatureDescriptor\"\xa4\x04\n\x13SignatureDescriptor\x12(\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.cosmos.tx.signing.v1beta1.SignatureDescriptor.Data\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x1a\x8d\x03\n\x04\x44\x61ta\x12L\n\x06single\x18\x01 \x01(\x0b\x32:.cosmos.tx.signing.v1beta1.SignatureDescriptor.Data.SingleH\x00\x12J\n\x05multi\x18\x02 \x01(\x0b\x32\x39.cosmos.tx.signing.v1beta1.SignatureDescriptor.Data.MultiH\x00\x1aN\n\x06Single\x12\x31\n\x04mode\x18\x01 \x01(\x0e\x32#.cosmos.tx.signing.v1beta1.SignMode\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x1a\x93\x01\n\x05Multi\x12\x41\n\x08\x62itarray\x18\x01 \x01(\x0b\x32/.cosmos.crypto.multisig.v1beta1.CompactBitArray\x12G\n\nsignatures\x18\x02 \x03(\x0b\x32\x33.cosmos.tx.signing.v1beta1.SignatureDescriptor.DataB\x05\n\x03sum*\xa5\x01\n\x08SignMode\x12\x19\n\x15SIGN_MODE_UNSPECIFIED\x10\x00\x12\x14\n\x10SIGN_MODE_DIRECT\x10\x01\x12\x15\n\x11SIGN_MODE_TEXTUAL\x10\x02\x12\x18\n\x14SIGN_MODE_DIRECT_AUX\x10\x03\x12\x1f\n\x1bSIGN_MODE_LEGACY_AMINO_JSON\x10\x7f\x12\x16\n\x11SIGN_MODE_EIP_191\x10\xbf\x01\x42/Z-github.com/cosmos/cosmos-sdk/types/tx/signingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.tx.signing.v1beta1.signing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/types/tx/signing'
  _globals['_SIGNMODE']._serialized_start=788
  _globals['_SIGNMODE']._serialized_end=953
  _globals['_SIGNATUREDESCRIPTORS']._serialized_start=144
  _globals['_SIGNATUREDESCRIPTORS']._serialized_end=234
  _globals['_SIGNATUREDESCRIPTOR']._serialized_start=237
  _globals['_SIGNATUREDESCRIPTOR']._serialized_end=785
  _globals['_SIGNATUREDESCRIPTOR_DATA']._serialized_start=388
  _globals['_SIGNATUREDESCRIPTOR_DATA']._serialized_end=785
  _globals['_SIGNATUREDESCRIPTOR_DATA_SINGLE']._serialized_start=550
  _globals['_SIGNATUREDESCRIPTOR_DATA_SINGLE']._serialized_end=628
  _globals['_SIGNATUREDESCRIPTOR_DATA_MULTI']._serialized_start=631
  _globals['_SIGNATUREDESCRIPTOR_DATA_MULTI']._serialized_end=778
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vest/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.vest import vest_entry_pb2 as dydxprotocol_dot_vest_dot_vest__entry__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x64ydxprotocol/vest/tx.proto\x12\x11\x64ydxprotocol.vest\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\"dydxprotocol/vest/vest_entry.proto\x1a\x14gogoproto/gogo.proto\"i\n\x12MsgDeleteVestEntry\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x16\n\x0evester_account\x18\x02 \x01(\t:\x0e\x82\xe7\xb0*\tauthority\"\x1c\n\x1aMsgDeleteVestEntryResponse\"\x81\x01\n\x0fMsgSetVestEntry\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x31\n\x05\x65ntry\x18\x02 \x01(\x0b\x32\x1c.dydxprotocol.vest.VestEntryB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgSetVestEntryResponse2\xce\x01\n\x03Msg\x12^\n\x0cSetVestEntry\x12\".dydxprotocol.vest.MsgSetVestEntry\x1a*.dydxprotocol.vest.MsgSetVestEntryResponse\x12g\n\x0f\x44\x65leteVestEntry\x12%.dydxprotocol.vest.MsgDeleteVestEntry\x1a-.dydxprotocol.vest.MsgDeleteVestEntryResponseB8Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vest.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/types'
  _globals['_MSGDELETEVESTENTRY'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGDELETEVESTENTRY'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGDELETEVESTENTRY']._loaded_options = None
  _globals['_MSGDELETEVESTENTRY']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETVESTENTRY'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETVESTENTRY'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETVESTENTRY'].fields_by_name['entry']._loaded_options = None
  _globals['_MSGSETVESTENTRY'].fields_by_name['entry']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVESTENTRY']._loaded_options = None
  _globals['_MSGSETVESTENTRY']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGDELETEVESTENTRY']._serialized_start=159
  _globals['_MSGDELETEVESTENTRY']._serialized_end=264
  _globals['_MSGDELETEVESTENTRYRESPONSE']._serialized_start=266
  _globals['_MSGDELETEVESTENTRYRESPONSE']._serialized_end=294
  _globals['_MSGSETVESTENTRY']._serialized_start=297
  _globals['_MSGSETVESTENTRY']._serialized_end=426
  _globals['_MSGSETVESTENTRYRESPONSE']._serialized_start=428
  _globals['_MSGSETVESTENTRYRESPONSE']._serialized_end=453
  _globals['_MSG']._serialized_start=456
  _globals['_MSG']._serialized_end=662
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.group.v1 import types_pb2 as _types_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryGroupInfoRequest(_message.Message):
    __slots__ = ("group_id",)
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: int
    def __init__(self, group_id: _Optional[int] = ...) -> None: ...

class QueryGroupInfoResponse(_message.Message):
    __slots__ = ("info",)
    INFO_FIELD_NUMBER: _ClassVar[int]
    info: _types_pb2.GroupInfo
    def __init__(self, info: _Optional[_Union[_types_pb2.GroupInfo, _Mapping]] = ...) -> None: ...

class QueryGroupPolicyInfoRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class QueryGroupPolicyInfoResponse(_message.Message):
    __slots__ = ("info",)
    INFO_FIELD_NUMBER: _ClassVar[int]
    info: _types_pb2.GroupPolicyInfo
    def __init__(self, info: _Optional[_Union[_types_pb2.GroupPolicyInfo, _Mapping]] = ...) -> None: ...

class QueryGroupMembersRequest(_message.Message):
    __slots__ = ("group_id", "pagination")
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    group_id: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, group_id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryGroupMembersResponse(_message.Message):
    __slots__ = ("members", "pagination")
    MEMBERS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    members: _containers.RepeatedCompositeFieldContainer[_types_pb2.GroupMember]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, members: _Optional[_Iterable[_Union[_types_pb2.GroupMember, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGroupsByAdminRequest(_message.Message):
    __slots__ = ("admin", "pagination")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    admin: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, admin: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryGroupsByAdminResponse(_message.Message):
    __slots__ = ("groups", "pagination")
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[_types_pb2.GroupInfo]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, groups: _Optional[_Iterable[_Union[_types_pb2.GroupInfo, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGroupPoliciesByGroupRequest(_message.Message):
    __slots__ = ("group_id", "pagination")
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    group_id: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, group_id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryGroupPoliciesByGroupResponse(_message.Message):
    __slots__ = ("group_policies", "pagination")
    GROUP_POLICIES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    group_policies: _containers.RepeatedCompositeFieldContainer[_types_pb2.GroupPolicyInfo]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, group_policies: _Optional[_Iterable[_Union[_types_pb2.GroupPolicyInfo, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGroupPoliciesByAdminRequest(_message.Message):
    __slots__ = ("admin", "pagination")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    admin: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, admin: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryGroupPoliciesByAdminResponse(_message.Message):
    __slots__ = ("group_policies", "pagination")
    GROUP_POLICIES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    group_policies: _containers.RepeatedCompositeFieldContainer[_types_pb2.GroupPolicyInfo]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, group_policies: _Optional[_Iterable[_Union[_types_pb2.GroupPolicyInfo, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryProposalRequest(_message.Message):
    __slots__ = ("proposal_id",)
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class QueryProposalResponse(_message.Message):
    __slots__ = ("proposal",)
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    proposal: _types_pb2.Proposal
    def __init__(self, proposal: _Optional[_Union[_types_pb2.Proposal, _Mapping]] = ...) -> None: ...

class QueryProposalsByGroupPolicyRequest(_message.Message):
    __slots__ = ("address", "pagination")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, address: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryProposalsByGroupPolicyResponse(_message.Message):
    __slots__ = ("proposals", "pagination")
    PROPOSALS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    proposals: _containers.RepeatedCompositeFieldContainer[_types_pb2.Proposal]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, proposals: _Optional[_Iterable[_Union[_types_pb2.Proposal, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryVoteByProposalVoterRequest(_message.Message):
    __slots__ = ("proposal_id", "voter")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    voter: str
    def __init__(self, proposal_id: _Optional[int] = ..., voter: _Optional[str] = ...) -> None: ...

class QueryVoteByProposalVoterResponse(_message.Message):
    __slots__ = ("vote",)
    VOTE_FIELD_NUMBER: _ClassVar[int]
    vote: _types_pb2.Vote
    def __init__(self, vote: _Optional[_Union[_types_pb2.Vote, _Mapping]] = ...) -> None: ...

class QueryVotesByProposalRequest(_message.Message):
    __slots__ = ("proposal_id", "pagination")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, proposal_id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryVotesByProposalResponse(_message.Message):
    __slots__ = ("votes", "pagination")
    VOTES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    votes: _containers.RepeatedCompositeFieldContainer[_types_pb2.Vote]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, votes: _Optional[_Iterable[_Union[_types_pb2.Vote, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryVotesByVoterRequest(_message.Message):
    __slots__ = ("voter", "pagination")
    VOTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    voter: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, voter: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryVotesByVoterResponse(_message.Message):
    __slots__ = ("votes", "pagination")
    VOTES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    votes: _containers.RepeatedCompositeFieldContainer[_types_pb2.Vote]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, votes: _Optional[_Iterable[_Union[_types_pb2.Vote, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGroupsByMemberRequest(_message.Message):
    __slots__ = ("address", "pagination")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, address: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryGroupsByMemberResponse(_message.Message):
    __slots__ = ("groups", "pagination")
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[_types_pb2.GroupInfo]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, groups: _Optional[_Iterable[_Union[_types_pb2.GroupInfo, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryTallyResultRequest(_message.Message):
    __slots__ = ("proposal_id",)
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class QueryTallyResultResponse(_message.Message):
    __slots__ = ("tally",)
    TALLY_FIELD_NUMBER: _ClassVar[int]
    tally: _types_pb2.TallyResult
    def __init__(self, tally: _Optional[_Union[_types_pb2.TallyResult, _Mapping]] = ...) -> None: ...

class QueryGroupsRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryGroupsResponse(_message.Message):
    __slots__ = ("groups", "pagination")
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[_types_pb2.GroupInfo]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, groups: _Optional[_Iterable[_Union[_types_pb2.GroupInfo, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.accountplus import accountplus_pb2 as _accountplus_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("accounts",)
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    accounts: _containers.RepeatedCompositeFieldContainer[_accountplus_pb2.AccountState]
    def __init__(self, accounts: _Optional[_Iterable[_Union[_accountplus_pb2.AccountState, _Mapping]]] = ...) -> None: ...



from v4_proto.cosmos.app.v1alpha1 import module_pb2 as _module_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Config(_message.Message):
    __slots__ = ("skip_ante_handler", "skip_post_handler")
    SKIP_ANTE_HANDLER_FIELD_NUMBER: _ClassVar[int]
    SKIP_POST_HANDLER_FIELD_NUMBER: _ClassVar[int]
    skip_ante_handler: bool
    skip_post_handler: bool
    def __init__(self, skip_ante_handler: bool = ..., skip_post_handler: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/subaccounts/asset_position.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-dydxprotocol/subaccounts/asset_position.proto\x12\x18\x64ydxprotocol.subaccounts\x1a\x14gogoproto/gogo.proto\"\x8c\x01\n\rAssetPosition\x12\x10\n\x08\x61sset_id\x18\x01 \x01(\r\x12Z\n\x08quantums\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\r\n\x05index\x18\x03 \x01(\x04\x42?Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.subaccounts.asset_position_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/types'
  _globals['_ASSETPOSITION'].fields_by_name['quantums']._loaded_options = None
  _globals['_ASSETPOSITION'].fields_by_name['quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_ASSETPOSITION']._serialized_start=98
  _globals['_ASSETPOSITION']._serialized_end=238
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/accountplus/accountplus.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*dydxprotocol/accountplus/accountplus.proto\x12\x18\x64ydxprotocol.accountplus\x1a\x14gogoproto/gogo.proto\"w\n\x0c\x41\x63\x63ountState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12V\n\x17timestamp_nonce_details\x18\x02 \x01(\x0b\x32/.dydxprotocol.accountplus.TimestampNonceDetailsB\x04\xc8\xde\x1f\x00\"L\n\x15TimestampNonceDetails\x12\x18\n\x10timestamp_nonces\x18\x01 \x03(\x04\x12\x19\n\x11max_ejected_nonce\x18\x02 \x01(\x04\x42?Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.accountplus.accountplus_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/types'
  _globals['_ACCOUNTSTATE'].fields_by_name['timestamp_nonce_details']._loaded_options = None
  _globals['_ACCOUNTSTATE'].fields_by_name['timestamp_nonce_details']._serialized_options = b'\310\336\037\000'
  _globals['_ACCOUNTSTATE']._serialized_start=94
  _globals['_ACCOUNTSTATE']._serialized_end=213
  _globals['_TIMESTAMPNONCEDETAILS']._serialized_start=215
  _globals['_TIMESTAMPNONCEDETAILS']._serialized_end=291
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Class(_message.Message):
    __slots__ = ("id", "name", "symbol", "description", "uri", "uri_hash", "data")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SYMBOL_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    URI_FIELD_NUMBER: _ClassVar[int]
    URI_HASH_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    symbol: str
    description: str
    uri: str
    uri_hash: str
    data: _any_pb2.Any
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., symbol: _Optional[str] = ..., description: _Optional[str] = ..., uri: _Optional[str] = ..., uri_hash: _Optional[str] = ..., data: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class NFT(_message.Message):
    __slots__ = ("class_id", "id", "uri", "uri_hash", "data")
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    URI_FIELD_NUMBER: _ClassVar[int]
    URI_HASH_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    id: str
    uri: str
    uri_hash: str
    data: _any_pb2.Any
    def __init__(self, class_id: _Optional[str] = ..., id: _Optional[str] = ..., uri: _Optional[str] = ..., uri_hash: _Optional[str] = ..., data: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/distribution/v1beta1/distribution.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.cosmos/distribution/v1beta1/distribution.proto\x12\x1b\x63osmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xce\x02\n\x06Params\x12M\n\rcommunity_tax\x18\x01 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12V\n\x14\x62\x61se_proposer_reward\x18\x02 \x01(\tB8\x18\x01\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12W\n\x15\x62onus_proposer_reward\x18\x03 \x01(\tB8\x18\x01\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12\x1d\n\x15withdraw_addr_enabled\x18\x04 \x01(\x08:%\x8a\xe7\xb0* cosmos-sdk/x/distribution/Params\"\xae\x01\n\x1aValidatorHistoricalRewards\x12w\n\x17\x63umulative_reward_ratio\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB8\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xa8\xe7\xb0*\x01\x12\x17\n\x0freference_count\x18\x02 \x01(\r\"\x92\x01\n\x17ValidatorCurrentRewards\x12g\n\x07rewards\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB8\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xa8\xe7\xb0*\x01\x12\x0e\n\x06period\x18\x02 \x01(\x04\"\x8c\x01\n\x1eValidatorAccumulatedCommission\x12j\n\ncommission\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB8\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xa8\xe7\xb0*\x01\"\x86\x01\n\x1bValidatorOutstandingRewards\x12g\n\x07rewards\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB8\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xa8\xe7\xb0*\x01\"t\n\x13ValidatorSlashEvent\x12\x18\n\x10validator_period\x18\x01 \x01(\x04\x12\x43\n\x08\x66raction\x18\x02 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\"s\n\x14ValidatorSlashEvents\x12[\n\x16validator_slash_events\x18\x01 \x03(\x0b\x32\x30.cosmos.distribution.v1beta1.ValidatorSlashEventB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"y\n\x07\x46\x65\x65Pool\x12n\n\x0e\x63ommunity_pool\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB8\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xa8\xe7\xb0*\x01\"\xf0\x01\n\x1a\x43ommunityPoolSpendProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\trecipient\x18\x03 \x01(\t\x12q\n\x06\x61mount\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01:(\x18\x01\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xb5\x01\n\x15\x44\x65legatorStartingInfo\x12\x17\n\x0fprevious_period\x18\x01 \x01(\x04\x12\x45\n\x05stake\x18\x02 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12<\n\x06height\x18\x03 \x01(\x04\x42,\xea\xde\x1f\x0f\x63reation_height\xa2\xe7\xb0*\x0f\x63reation_height\xa8\xe7\xb0*\x01\"\xc7\x01\n\x19\x44\x65legationDelegatorReward\x12<\n\x11validator_address\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12\x66\n\x06reward\x18\x02 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB8\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xa8\xe7\xb0*\x01:\x04\x88\xa0\x1f\x00\"\xa3\x01\n%CommunityPoolSpendProposalWithDeposit\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\trecipient\x18\x03 \x01(\t\x12\x0e\n\x06\x61mount\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65posit\x18\x05 \x01(\t:\"\x88\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.ContentB7Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.distribution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\250\342\036\001'
  _globals['_PARAMS'].fields_by_name['community_tax']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['community_tax']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['base_proposer_reward']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['base_proposer_reward']._serialized_options = b'\030\001\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['bonus_proposer_reward']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['bonus_proposer_reward']._serialized_options = b'\030\001\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\212\347\260* cosmos-sdk/x/distribution/Params'
  _globals['_VALIDATORHISTORICALREWARDS'].fields_by_name['cumulative_reward_ratio']._loaded_options = None
  _globals['_VALIDATORHISTORICALREWARDS'].fields_by_name['cumulative_reward_ratio']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins\250\347\260*\001'
  _globals['_VALIDATORCURRENTREWARDS'].fields_by_name['rewards']._loaded_options = None
  _globals['_VALIDATORCURRENTREWARDS'].fields_by_name['rewards']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins\250\347\260*\001'
  _globals['_VALIDATORACCUMULATEDCOMMISSION'].fields_by_name['commission']._loaded_options = None
  _globals['_VALIDATORACCUMULATEDCOMMISSION'].fields_by_name['commission']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins\250\347\260*\001'
  _globals['_VALIDATOROUTSTANDINGREWARDS'].fields_by_name['rewards']._loaded_options = None
  _globals['_VALIDATOROUTSTANDINGREWARDS'].fields_by_name['rewards']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins\250\347\260*\001'
  _globals['_VALIDATORSLASHEVENT'].fields_by_name['fraction']._loaded_options = None
  _globals['_VALIDATORSLASHEVENT'].fields_by_name['fraction']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_VALIDATORSLASHEVENTS'].fields_by_name['validator_slash_events']._loaded_options = None
  _globals['_VALIDATORSLASHEVENTS'].fields_by_name['validator_slash_events']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_FEEPOOL'].fields_by_name['community_pool']._loaded_options = None
  _globals['_FEEPOOL'].fields_by_name['community_pool']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins\250\347\260*\001'
  _globals['_COMMUNITYPOOLSPENDPROPOSAL'].fields_by_name['amount']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSAL'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_COMMUNITYPOOLSPENDPROPOSAL']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSAL']._serialized_options = b'\030\001\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_DELEGATORSTARTINGINFO'].fields_by_name['stake']._loaded_options = None
  _globals['_DELEGATORSTARTINGINFO'].fields_by_name['stake']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_DELEGATORSTARTINGINFO'].fields_by_name['height']._loaded_options = None
  _globals['_DELEGATORSTARTINGINFO'].fields_by_name['height']._serialized_options = b'\352\336\037\017creation_height\242\347\260*\017creation_height\250\347\260*\001'
  _globals['_DELEGATIONDELEGATORREWARD'].fields_by_name['validator_address']._loaded_options = None
  _globals['_DELEGATIONDELEGATORREWARD'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_DELEGATIONDELEGATORREWARD'].fields_by_name['reward']._loaded_options = None
  _globals['_DELEGATIONDELEGATORREWARD'].fields_by_name['reward']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins\250\347\260*\001'
  _globals['_DELEGATIONDELEGATORREWARD']._loaded_options = None
  _globals['_DELEGATIONDELEGATORREWARD']._serialized_options = b'\210\240\037\000'
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT']._serialized_options = b'\210\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_PARAMS']._serialized_start=180
  _globals['_PARAMS']._serialized_end=514
  _globals['_VALIDATORHISTORICALREWARDS']._serialized_start=517
  _globals['_VALIDATORHISTORICALREWARDS']._serialized_end=691
  _globals['_VALIDATORCURRENTREWARDS']._serialized_start=694
  _globals['_VALIDATORCURRENTREWARDS']._serialized_end=840
  _globals['_VALIDATORACCUMULATEDCOMMISSION']._serialized_start=843
  _globals['_VALIDATORACCUMULATEDCOMMISSION']._serialized_end=983
  _globals['_VALIDATOROUTSTANDINGREWARDS']._serialized_start=986
  _globals['_VALIDATOROUTSTANDINGREWARDS']._serialized_end=1120
  _globals['_VALIDATORSLASHEVENT']._serialized_start=1122
  _globals['_VALIDATORSLASHEVENT']._serialized_end=1238
  _globals['_VALIDATORSLASHEVENTS']._serialized_start=1240
  _globals['_VALIDATORSLASHEVENTS']._serialized_end=1355
  _globals['_FEEPOOL']._serialized_start=1357
  _globals['_FEEPOOL']._serialized_end=1478
  _globals['_COMMUNITYPOOLSPENDPROPOSAL']._serialized_start=1481
  _globals['_COMMUNITYPOOLSPENDPROPOSAL']._serialized_end=1721
  _globals['_DELEGATORSTARTINGINFO']._serialized_start=1724
  _globals['_DELEGATORSTARTINGINFO']._serialized_end=1905
  _globals['_DELEGATIONDELEGATORREWARD']._serialized_start=1908
  _globals['_DELEGATIONDELEGATORREWARD']._serialized_end=2107
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT']._serialized_start=2110
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT']._serialized_end=2273
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class QueryMarketsHardCap(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryMarketsHardCapResponse(_message.Message):
    __slots__ = ("hard_cap",)
    HARD_CAP_FIELD_NUMBER: _ClassVar[int]
    hard_cap: int
    def __init__(self, hard_cap: _Optional[int] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.prices import market_param_pb2 as _market_param_pb2
from v4_proto.dydxprotocol.prices import market_price_pb2 as _market_price_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("market_params", "market_prices")
    MARKET_PARAMS_FIELD_NUMBER: _ClassVar[int]
    MARKET_PRICES_FIELD_NUMBER: _ClassVar[int]
    market_params: _containers.RepeatedCompositeFieldContainer[_market_param_pb2.MarketParam]
    market_prices: _containers.RepeatedCompositeFieldContainer[_market_price_pb2.MarketPrice]
    def __init__(self, market_params: _Optional[_Iterable[_Union[_market_param_pb2.MarketParam, _Mapping]]] = ..., market_prices: _Optional[_Iterable[_Union[_market_price_pb2.MarketPrice, _Mapping]]] = ...) -> None: ...
